import { ChainName, ChainsConfig, Contracts, TokenId } from '@wormhole-foundation/connect-sdk';
import * as ethers_contracts from './ethers-contracts';
import { Provider } from 'ethers';
/**
 * @category EVM
 * Evm Contracts class. Contains methods for accessing ts interfaces for all available contracts
 */
export declare class EvmContracts {
    protected _contracts: Map<ChainName, Contracts>;
    constructor(conf: ChainsConfig);
    /**
     * Returns contract addresses for the chain
     *
     * @returns The contract addresses
     */
    getContracts(chain: ChainName): Contracts;
    /**
     * Returns core wormhole contract for the chain
     *
     * @returns An interface for the core contract, errors if not found
     */
    getCore(chain: ChainName, connection: Provider): ethers_contracts.Wormhole;
    /**
     * Returns wormhole bridge contract for the chain
     *
     * @returns An interface for the bridge contract, errors if not found
     */
    getTokenBridge(chain: ChainName, connection: Provider): ethers_contracts.TokenBridgeContract;
    static getTokenImplementation(connection: Provider, address: string): ethers_contracts.TokenImplementation;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, undefined if not found
     */
    getNftBridge(chain: ChainName, connection: Provider): ethers_contracts.NFTBridge | undefined;
    /**
     * Returns wormhole NFT bridge contract for the chain
     *
     * @returns An interface for the NFT bridge contract, errors if not found
     */
    mustGetNftBridge(chain: ChainName, connection: Provider): ethers_contracts.NFTBridge;
    /**
     * Returns wormhole Token Bridge Relayer contract for the chain
     *
     * @returns An interface for the Token Bridge Relayer contract, errors if not found
     */
    getTokenBridgeRelayer(chain: ChainName, connection: Provider): ethers_contracts.TokenBridgeRelayer;
    /**
     * Returns wormhole CCTP relayer contract for the chain
     *
     * @returns An interface for the Wormhole CCTP relayer contract, errors if not found
     */
    getWormholeCircleRelayer(chain: ChainName, connection: Provider): ethers_contracts.CircleRelayer;
    getCircleTokenMessenger(chain: ChainName, connection: Provider): ethers_contracts.TokenMessenger.TokenMessenger;
    getCircleMessageTransmitter(chain: ChainName, connection: Provider): ethers_contracts.MessageTransmitter.MessageTransmitter;
    getCoreImplementationInterface(): ethers_contracts.ImplementationInterface;
    getCoreImplementation(chain: ChainName, connection: Provider): ethers_contracts.Implementation;
    getNativeWrapped(chain: ChainName, connection: Provider): Promise<TokenId>;
}
//# sourceMappingURL=contracts.d.ts.map