"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EvmPlatform = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const ethers_1 = require("ethers");
const contracts_1 = require("./contracts");
const chain_1 = require("./chain");
const tokenBridge_1 = require("./protocols/tokenBridge");
const automaticTokenBridge_1 = require("./protocols/automaticTokenBridge");
const automaticCircleBridge_1 = require("./protocols/automaticCircleBridge");
const circleBridge_1 = require("./protocols/circleBridge");
const wormholeCore_1 = require("./protocols/wormholeCore");
const platformUtils_1 = require("./platformUtils");
// forces EvmPlatform to implement Platform
var _ = EvmPlatform;
/**
 * @category EVM
 */
// Provides runtime concrete value
var EvmPlatform;
(function (EvmPlatform) {
    EvmPlatform.platform = 'Evm';
    EvmPlatform.network = connect_sdk_1.DEFAULT_NETWORK;
    EvmPlatform.conf = (0, connect_sdk_1.networkPlatformConfigs)(EvmPlatform.network, EvmPlatform.platform);
    let contracts = new contracts_1.EvmContracts(EvmPlatform.conf);
    EvmPlatform.nativeTokenId = platformUtils_1.EvmUtils.nativeTokenId, EvmPlatform.isNativeTokenId = platformUtils_1.EvmUtils.isNativeTokenId, EvmPlatform.isSupportedChain = platformUtils_1.EvmUtils.isSupportedChain, EvmPlatform.getDecimals = platformUtils_1.EvmUtils.getDecimals, EvmPlatform.getBalance = platformUtils_1.EvmUtils.getBalance, EvmPlatform.sendWait = platformUtils_1.EvmUtils.sendWait, EvmPlatform.getCurrentBlock = platformUtils_1.EvmUtils.getCurrentBlock, EvmPlatform.chainFromRpc = platformUtils_1.EvmUtils.chainFromRpc;
    function setConfig(network, _conf) {
        EvmPlatform.conf = _conf ? _conf : (0, connect_sdk_1.networkPlatformConfigs)(network, EvmPlatform.platform);
        contracts = new contracts_1.EvmContracts(EvmPlatform.conf);
        return EvmPlatform;
    }
    EvmPlatform.setConfig = setConfig;
    function getRpc(chain) {
        const rpcAddress = EvmPlatform.conf[chain].rpc;
        return ethers_1.ethers.getDefaultProvider(rpcAddress);
    }
    EvmPlatform.getRpc = getRpc;
    function getChain(chain) {
        return new chain_1.EvmChain(chain);
    }
    EvmPlatform.getChain = getChain;
    function getWormholeCore(rpc) {
        return wormholeCore_1.EvmWormholeCore.fromProvider(rpc, contracts);
    }
    EvmPlatform.getWormholeCore = getWormholeCore;
    async function getTokenBridge(rpc) {
        return await tokenBridge_1.EvmTokenBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getTokenBridge = getTokenBridge;
    async function getAutomaticTokenBridge(rpc) {
        return await automaticTokenBridge_1.EvmAutomaticTokenBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getAutomaticTokenBridge = getAutomaticTokenBridge;
    async function getCircleBridge(rpc) {
        return await circleBridge_1.EvmCircleBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getCircleBridge = getCircleBridge;
    async function getAutomaticCircleBridge(rpc) {
        return await automaticCircleBridge_1.EvmAutomaticCircleBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getAutomaticCircleBridge = getAutomaticCircleBridge;
    async function parseTransaction(chain, rpc, txid) {
        const receipt = await rpc.getTransactionReceipt(txid);
        if (receipt === null)
            throw new Error(`No transaction found with txid: ${txid}`);
        const coreAddress = EvmPlatform.conf[chain].contracts.coreBridge;
        const coreImpl = contracts.getCoreImplementationInterface();
        return receipt.logs
            .filter((l) => {
            return l.address === coreAddress;
        })
            .map((log) => {
            const { topics, data } = log;
            const parsed = coreImpl.parseLog({ topics: topics.slice(), data });
            if (parsed === null)
                return undefined;
            const emitterAddress = (0, connect_sdk_1.toNative)(chain, parsed.args.sender);
            return {
                chain: chain,
                emitter: emitterAddress.toUniversalAddress(),
                sequence: parsed.args.sequence,
            };
        })
            .filter(connect_sdk_1.isWormholeMessageId);
    }
    EvmPlatform.parseTransaction = parseTransaction;
})(EvmPlatform || (exports.EvmPlatform = EvmPlatform = {}));
//# sourceMappingURL=platform.js.map