"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EvmWormholeCore = void 0;
const constants_1 = require("../constants");
const unsignedTransaction_1 = require("../unsignedTransaction");
const types_1 = require("../types");
const platform_1 = require("../platform");
class EvmWormholeCore {
    network;
    chain;
    provider;
    contracts;
    chainId;
    core;
    coreIface;
    constructor(network, chain, provider, contracts) {
        this.network = network;
        this.chain = chain;
        this.provider = provider;
        this.contracts = contracts;
        this.chainId = constants_1.evmNetworkChainToEvmChainId.get(network, chain);
        this.core = this.contracts.getCoreImplementation(chain, provider);
        this.coreIface = this.contracts.getCoreImplementationInterface();
    }
    static async fromProvider(provider, contracts) {
        const [network, chain] = await platform_1.EvmPlatform.chainFromRpc(provider);
        return new EvmWormholeCore(network, chain, provider, contracts);
    }
    async *publishMessage(sender, message) {
        const senderAddr = (0, types_1.toEvmAddrString)(sender);
        const txReq = await this.core.publishMessage.populateTransaction(0, message, 200);
        yield this.createUnsignedTx((0, types_1.addFrom)(txReq, senderAddr), 'WormholeCore.publishMessage');
    }
    // async parseTransactionDetails(
    //   txid: TxHash,
    // ): Promise<TokenTransferTransaction[]> {
    //   const receipt = await this.provider.getTransactionReceipt(txid);
    //   if (receipt === null)
    //     throw new Error(`No transaction found with txid: ${txid}`);
    // }
    createUnsignedTx(txReq, description, parallelizable = false) {
        return new unsignedTransaction_1.EvmUnsignedTransaction((0, types_1.addChainId)(txReq, this.chainId), this.network, this.chain, description, parallelizable);
    }
}
exports.EvmWormholeCore = EvmWormholeCore;
//# sourceMappingURL=wormholeCore.js.map