import { ChainName, TxHash, WormholeMessageId, ChainsConfig, Network } from '@wormhole-foundation/connect-sdk';
import { ethers } from 'ethers';
import { EvmChain } from './chain';
import { EvmTokenBridge } from './protocols/tokenBridge';
import { EvmAutomaticTokenBridge } from './protocols/automaticTokenBridge';
import { EvmAutomaticCircleBridge } from './protocols/automaticCircleBridge';
import { EvmCircleBridge } from './protocols/circleBridge';
import { EvmWormholeCore } from './protocols/wormholeCore';
import { EvmUtils } from './platformUtils';
/**
 * @category EVM
 */
export declare module EvmPlatform {
    const platform = "Evm";
    const network: Network;
    let conf: ChainsConfig;
    type Type = typeof platform;
    const nativeTokenId: typeof EvmUtils.nativeTokenId, isNativeTokenId: typeof EvmUtils.isNativeTokenId, isSupportedChain: typeof EvmUtils.isSupportedChain, getDecimals: typeof EvmUtils.getDecimals, getBalance: typeof EvmUtils.getBalance, sendWait: typeof EvmUtils.sendWait, getCurrentBlock: typeof EvmUtils.getCurrentBlock, chainFromRpc: typeof EvmUtils.chainFromRpc;
    function setConfig(network: Network, _conf?: ChainsConfig): typeof EvmPlatform;
    function getRpc(chain: ChainName): ethers.Provider;
    function getChain(chain: ChainName): EvmChain;
    function getWormholeCore(rpc: ethers.Provider): Promise<EvmWormholeCore>;
    function getTokenBridge(rpc: ethers.Provider): Promise<EvmTokenBridge>;
    function getAutomaticTokenBridge(rpc: ethers.Provider): Promise<EvmAutomaticTokenBridge>;
    function getCircleBridge(rpc: ethers.Provider): Promise<EvmCircleBridge>;
    function getAutomaticCircleBridge(rpc: ethers.Provider): Promise<EvmAutomaticCircleBridge>;
    function parseTransaction(chain: ChainName, rpc: ethers.Provider, txid: TxHash): Promise<WormholeMessageId[]>;
}
//# sourceMappingURL=platform.d.ts.map