import { isWormholeMessageId, networkPlatformConfigs, DEFAULT_NETWORK, toNative, } from '@wormhole-foundation/connect-sdk';
import { ethers } from 'ethers';
import { EvmContracts } from './contracts';
import { EvmChain } from './chain';
import { EvmTokenBridge } from './protocols/tokenBridge';
import { EvmAutomaticTokenBridge } from './protocols/automaticTokenBridge';
import { EvmAutomaticCircleBridge } from './protocols/automaticCircleBridge';
import { EvmCircleBridge } from './protocols/circleBridge';
import { EvmWormholeCore } from './protocols/wormholeCore';
import { EvmUtils } from './platformUtils';
// forces EvmPlatform to implement Platform
var _ = EvmPlatform;
/**
 * @category EVM
 */
// Provides runtime concrete value
export var EvmPlatform;
(function (EvmPlatform) {
    EvmPlatform.platform = 'Evm';
    EvmPlatform.network = DEFAULT_NETWORK;
    EvmPlatform.conf = networkPlatformConfigs(EvmPlatform.network, EvmPlatform.platform);
    let contracts = new EvmContracts(EvmPlatform.conf);
    EvmPlatform.nativeTokenId = EvmUtils.nativeTokenId, EvmPlatform.isNativeTokenId = EvmUtils.isNativeTokenId, EvmPlatform.isSupportedChain = EvmUtils.isSupportedChain, EvmPlatform.getDecimals = EvmUtils.getDecimals, EvmPlatform.getBalance = EvmUtils.getBalance, EvmPlatform.sendWait = EvmUtils.sendWait, EvmPlatform.getCurrentBlock = EvmUtils.getCurrentBlock, EvmPlatform.chainFromRpc = EvmUtils.chainFromRpc;
    function setConfig(network, _conf) {
        EvmPlatform.conf = _conf ? _conf : networkPlatformConfigs(network, EvmPlatform.platform);
        contracts = new EvmContracts(EvmPlatform.conf);
        return EvmPlatform;
    }
    EvmPlatform.setConfig = setConfig;
    function getRpc(chain) {
        const rpcAddress = EvmPlatform.conf[chain].rpc;
        return ethers.getDefaultProvider(rpcAddress);
    }
    EvmPlatform.getRpc = getRpc;
    function getChain(chain) {
        return new EvmChain(chain);
    }
    EvmPlatform.getChain = getChain;
    function getWormholeCore(rpc) {
        return EvmWormholeCore.fromProvider(rpc, contracts);
    }
    EvmPlatform.getWormholeCore = getWormholeCore;
    async function getTokenBridge(rpc) {
        return await EvmTokenBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getTokenBridge = getTokenBridge;
    async function getAutomaticTokenBridge(rpc) {
        return await EvmAutomaticTokenBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getAutomaticTokenBridge = getAutomaticTokenBridge;
    async function getCircleBridge(rpc) {
        return await EvmCircleBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getCircleBridge = getCircleBridge;
    async function getAutomaticCircleBridge(rpc) {
        return await EvmAutomaticCircleBridge.fromProvider(rpc, contracts);
    }
    EvmPlatform.getAutomaticCircleBridge = getAutomaticCircleBridge;
    async function parseTransaction(chain, rpc, txid) {
        const receipt = await rpc.getTransactionReceipt(txid);
        if (receipt === null)
            throw new Error(`No transaction found with txid: ${txid}`);
        const coreAddress = EvmPlatform.conf[chain].contracts.coreBridge;
        const coreImpl = contracts.getCoreImplementationInterface();
        return receipt.logs
            .filter((l) => {
            return l.address === coreAddress;
        })
            .map((log) => {
            const { topics, data } = log;
            const parsed = coreImpl.parseLog({ topics: topics.slice(), data });
            if (parsed === null)
                return undefined;
            const emitterAddress = toNative(chain, parsed.args.sender);
            return {
                chain: chain,
                emitter: emitterAddress.toUniversalAddress(),
                sequence: parsed.args.sequence,
            };
        })
            .filter(isWormholeMessageId);
    }
    EvmPlatform.parseTransaction = parseTransaction;
})(EvmPlatform || (EvmPlatform = {}));
//# sourceMappingURL=platform.js.map