import { nativeDecimals, chainToPlatform, } from '@wormhole-foundation/connect-sdk';
import { evmChainIdToNetworkChainPair } from './constants';
import { EvmAddress, EvmZeroAddress } from './address';
import { EvmContracts } from './contracts';
import { EvmPlatform } from './platform';
// forces EvmUtils to implement PlatformUtils
var _ = EvmUtils;
/**
 * @category EVM
 */
// Provides runtime concrete value
export var EvmUtils;
(function (EvmUtils) {
    function nativeTokenId(chain) {
        if (!isSupportedChain(chain))
            throw new Error(`invalid chain for EVM: ${chain}`);
        return {
            chain: chain,
            address: new EvmAddress(EvmZeroAddress), // TODO: fix weird type error
        };
    }
    EvmUtils.nativeTokenId = nativeTokenId;
    function isSupportedChain(chain) {
        const platform = chainToPlatform(chain);
        return platform === EvmPlatform.platform;
    }
    EvmUtils.isSupportedChain = isSupportedChain;
    function isNativeTokenId(chain, tokenId) {
        if (!isSupportedChain(chain))
            return false;
        if (tokenId.chain !== chain)
            return false;
        return tokenId.address.toString() === EvmZeroAddress;
    }
    EvmUtils.isNativeTokenId = isNativeTokenId;
    async function getDecimals(chain, rpc, tokenId) {
        if (tokenId === 'native')
            return nativeDecimals(EvmPlatform.platform);
        const tokenContract = EvmContracts.getTokenImplementation(rpc, tokenId.address.toString());
        const decimals = await tokenContract.decimals();
        return decimals;
    }
    EvmUtils.getDecimals = getDecimals;
    async function getBalance(chain, rpc, walletAddr, tokenId) {
        if (tokenId === 'native')
            return await rpc.getBalance(walletAddr);
        const token = EvmContracts.getTokenImplementation(rpc, tokenId.address.toString());
        const balance = await token.balanceOf(walletAddr);
        return balance;
    }
    EvmUtils.getBalance = getBalance;
    async function sendWait(chain, rpc, stxns) {
        const txhashes = [];
        for (const stxn of stxns) {
            const txRes = await rpc.broadcastTransaction(stxn);
            txhashes.push(txRes.hash);
            if (chain === 'Celo') {
                console.error('TODO: override celo block fetching');
                continue;
            }
            // Wait for confirmation
            const txReceipt = await txRes.wait();
            if (txReceipt === null)
                continue; // TODO: throw error?
        }
        return txhashes;
    }
    EvmUtils.sendWait = sendWait;
    async function getCurrentBlock(rpc) {
        return await rpc.getBlockNumber();
    }
    EvmUtils.getCurrentBlock = getCurrentBlock;
    async function chainFromRpc(rpc) {
        const { chainId } = await rpc.getNetwork();
        const networkChainPair = evmChainIdToNetworkChainPair.get(chainId);
        if (networkChainPair === undefined)
            throw new Error(`Unknown EVM chainId ${chainId}`);
        const [network, chain] = networkChainPair;
        return [network, chain];
    }
    EvmUtils.chainFromRpc = chainFromRpc;
})(EvmUtils || (EvmUtils = {}));
//# sourceMappingURL=platformUtils.js.map