import { chainToChainId, } from '@wormhole-foundation/connect-sdk';
import { evmNetworkChainToEvmChainId } from '../constants';
import { addChainId, addFrom, toEvmAddrString, } from '../types';
import { EvmUnsignedTransaction } from '../unsignedTransaction';
import { EvmContracts } from '../contracts';
import { EvmPlatform } from '../platform';
export class EvmAutomaticCircleBridge {
    network;
    chain;
    provider;
    contracts;
    circleRelayer;
    chainId;
    // https://github.com/wormhole-foundation/wormhole-connect/blob/development/sdk/src/contexts/eth/context.ts#L379
    constructor(network, chain, provider, contracts) {
        this.network = network;
        this.chain = chain;
        this.provider = provider;
        this.contracts = contracts;
        if (network === 'Devnet')
            throw new Error('AutomaticCircleBridge not supported on Devnet');
        this.chainId = evmNetworkChainToEvmChainId(network, chain);
        this.circleRelayer = this.contracts.getWormholeCircleRelayer(chain, provider);
    }
    static async fromProvider(provider, contracts) {
        const [network, chain] = await EvmPlatform.chainFromRpc(provider);
        return new EvmAutomaticCircleBridge(network, chain, provider, contracts);
    }
    async *transfer(token, sender, recipient, amount, nativeGas) {
        const senderAddr = toEvmAddrString(sender);
        const recipientChainId = chainToChainId(recipient.chain);
        const recipientAddress = recipient.address
            .toUniversalAddress()
            .toUint8Array();
        const nativeTokenGas = nativeGas ? nativeGas : 0n;
        const tokenAddr = toEvmAddrString(token.address.toUniversalAddress());
        const tokenContract = EvmContracts.getTokenImplementation(this.provider, tokenAddr);
        const allowance = await tokenContract.allowance(senderAddr, this.circleRelayer.target);
        if (allowance < amount) {
            const txReq = await tokenContract.approve.populateTransaction(this.circleRelayer.target, amount);
            yield this.createUnsignedTx(addFrom(txReq, senderAddr), 'ERC20.approve of CircleRelayer');
        }
        const txReq = await this.circleRelayer.transferTokensWithRelay.populateTransaction(tokenAddr, amount, nativeTokenGas, recipientChainId, recipientAddress);
        yield this.createUnsignedTx(addFrom(txReq, senderAddr), 'CircleRelayer.transfer');
    }
    createUnsignedTx(txReq, description, parallelizable = false) {
        return new EvmUnsignedTransaction(addChainId(txReq, this.chainId), this.network, this.chain, description, parallelizable);
    }
}
//# sourceMappingURL=automaticCircleBridge.js.map