import { evmNetworkChainToEvmChainId, } from '../constants';
import { EvmUnsignedTransaction } from '../unsignedTransaction';
import { addChainId, addFrom, toEvmAddrString, } from '../types';
import { EvmPlatform } from '../platform';
export class EvmWormholeCore {
    network;
    chain;
    provider;
    contracts;
    chainId;
    core;
    coreIface;
    constructor(network, chain, provider, contracts) {
        this.network = network;
        this.chain = chain;
        this.provider = provider;
        this.contracts = contracts;
        this.chainId = evmNetworkChainToEvmChainId.get(network, chain);
        this.core = this.contracts.getCoreImplementation(chain, provider);
        this.coreIface = this.contracts.getCoreImplementationInterface();
    }
    static async fromProvider(provider, contracts) {
        const [network, chain] = await EvmPlatform.chainFromRpc(provider);
        return new EvmWormholeCore(network, chain, provider, contracts);
    }
    async *publishMessage(sender, message) {
        const senderAddr = toEvmAddrString(sender);
        const txReq = await this.core.publishMessage.populateTransaction(0, message, 200);
        yield this.createUnsignedTx(addFrom(txReq, senderAddr), 'WormholeCore.publishMessage');
    }
    // async parseTransactionDetails(
    //   txid: TxHash,
    // ): Promise<TokenTransferTransaction[]> {
    //   const receipt = await this.provider.getTransactionReceipt(txid);
    //   if (receipt === null)
    //     throw new Error(`No transaction found with txid: ${txid}`);
    // }
    createUnsignedTx(txReq, description, parallelizable = false) {
        return new EvmUnsignedTransaction(addChainId(txReq, this.chainId), this.network, this.chain, description, parallelizable);
    }
}
//# sourceMappingURL=wormholeCore.js.map